@@ -14,6 +14,22 @@ function (linebuffer, cursorPosition = nchar(linebuffer), minlength = 2,
     comps <- utils:::.retrieveCompletions()
     if (!length(comps)) return(invisible(NULL))
 
+    # For tokens like "a[m", the actual token should be "m"
+    # completions are modified accordingly
+    rx <- regexpr("[[]+", token)
+    if (rx > 0) {
+    	# then we need to trim out whatever is before the [ in the completion
+    	# and the token
+    	start <- rx + attr(rx, "match.length")
+    	token <- substring(token, start)
+    	comps <- substring(comps, start)
+    }
+
+    # remove weird object names (useful when the token starts with ".")
+    comps <- comps[ !grepl( "^[.]__[[:alpha:]]__", comps ) ]
+    if (!length(comps))
+		return(invisible(NULL))
+
     # restrict the completion for which information is gathered (speed things up)
     if (!"arguments" %in% types)
 		comps <- comps[regexpr("=$", comps) < 0]
@@ -53,7 +69,7 @@ function (linebuffer, cursorPosition = nchar(linebuffer), minlength = 2,
     }
 
 		# deal with completions with "$"
-		if (length(test.dollar <- grep("\\$", comps))) {
+		if (length(test.dollar <- grep("\\$", comps)) ) {
 			elements <- comps[test.dollar]
 			object <- gsub("\\$.*$", "", comps)[1]
 			after <- gsub("^.*\\$", "", comps)
@@ -105,6 +121,8 @@ function (linebuffer, cursorPosition = nchar(linebuffer), minlength = 2,
 	# Make sure that arguments are witten 'arg = ', and not 'arg='
 	out[, 1] <- sub("=$", " = ", out[, 1])
 
+	attr( out, "token" ) <- token
+
 	if (simplify) {
 		cat(apply(out, 1, paste, collapse = "\t"), sep = "\n")
 	} else {
