@@ -10,11 +10,10 @@ function (topic, package = NULL, lib.loc = NULL)
 	# arguments in R 2.11... and it is DEPRECATED in R 2.10
 	# => need to use a different code here!!!
 	# This is a temporary hack for svMisc to pass R CMD check on these versions
-	if (exists("index.search", mode= "function")) {
-		file <- index.search(topic, INDICES, "AnIndex", "R-ex")
-	} else {
-		file <- ""
+	if (!exists("index.search", mode= "function")) {
+		index.search <- function (...) return("")
 	}
+	file <- index.search(topic, INDICES, "AnIndex", "R-ex")
 	# Neither help, nor example
 	if (file == "") return(c(help = FALSE, example = FALSE))
     packagePath <- dirname(dirname(file))
